<?php
/**
 *  YSP THEME FINE TUNE
 *
 * Options
 *  01  Disable Default Emoji Scripts
 *	02  Disable Default Dashicons Scripts
 *	03  Remove Assets Version
 *  04  Disable jQuery Migrate
 *  05  Disable Block Editor Assets
 *  06  Disable ScrollMagic Scripts
 *  07  Disable Animations
 * 
 * Extra
 *  01  Remove Comment Form Allowed Tags
 *  02  Customize Comment Form Place Holder Input Text Fields & Labels
 *  03  Customize Comment Form Text Area & Label
 *  04  Customize Search Form Layout
 *  05  Removes empty paragraph tags (<p></p>) and line break tags (<br>) from shortcodes caused by WordPress's wpautop function.
 *  06  Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *	07  Sets the authordata global when viewing an author archive.
 *  08  We will need the following filter function to disable TinyMCE emojicons.
 *  09  Remove emoji CDN hostname from DNS prefetching hints.
 *  10  Allow shortcodes in text widget, widget title, menu titles.
 *  11  Custom WP gallery style and use our own style.
 *  12  Allow SVG upload
 *  13  Support Custom Walkers
 *
 * @package yourstyle_plus
 *
 */

/********************
    Options
********************/

/**
 * 01
 * 
 * Enhance Default Emoji Scripts
 */

if ( '1' != ysp_get_option('ysp-enhance-emoji-scripts') ) {
	add_action( 'init', 'ysp_enhance_emoji_scripts' );
}

if (!function_exists('ysp_enhance_emoji_scripts')) {
    function ysp_enhance_emoji_scripts() {
        // all actions related to emojis
        remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
        remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
        remove_action( 'wp_print_styles', 'print_emoji_styles' );
        remove_action( 'admin_print_styles', 'print_emoji_styles' );	
        remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
        remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );	
        remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );

        // filter to remove TinyMCE emojis
        add_filter( 'tiny_mce_plugins', 'ysp_disable_emojicons_tinymce' );

        // remove the DNS prefetch by returning false on filter emoji_svg_url 
        add_filter( 'wp_resource_hints', 'ysp_disable_emojis_remove_dns_prefetch', 10, 2 );
    }
}

/**
 * 02
 * 
 * Enhance Default Dashicons Scripts
 * Notice: disabled only for logged out users
 */

if ( '1' != ysp_get_option('ysp-enhance-dashicons-scripts') ) {
	add_action( 'wp_enqueue_scripts', 'ysp_enhance_dashicons_scripts' );
}

if (!function_exists('ysp_enhance_dashicons_scripts')) {
    function ysp_enhance_dashicons_scripts() {
        if ( !is_user_logged_in() && !in_array( $_SERVER['PHP_SELF'], array( '/wp-login.php', '/wp-register.php' ) ) ) {
            wp_deregister_style( 'dashicons' );
            wp_deregister_style( 'editor' );
        }
    }
}

/**
 * 03
 * 
 * Enhance Assets Version
 * @param string $src Scripts and scripts.
 * @return string
 */
if ( '1' != ysp_get_option('ysp-enhance-assets-version') ) {
    // enhance assets version
    add_filter( 'script_loader_src', 'ysp_enhance_assets_version', 15, 1 );
    add_filter( 'style_loader_src', 'ysp_enhance_assets_version', 15, 1 );

    // completely remove your WordPress version number from both your head file and RSS feeds
    add_filter( 'the_generator', 'wp_remove_version' );
    remove_action( 'wp_head', 'wp_generator' );
}

if (!function_exists('ysp_enhance_assets_version')) {
    function ysp_enhance_assets_version( $src ) {
        $parts = explode( '?ver', $src );
        return $parts[0];
    }
}

function wp_remove_version() {
    return '';
}

/**
 * 04
 * 
 * Enhance jQuery Migrate
 */

if ( '1' != ysp_get_option('ysp-enhance-jquery-migrate') ) {
	add_action( 'wp_default_scripts', 'ysp_enhance_jquery_migrate' );
}

if (!function_exists('ysp_enhance_jquery_migrate')) {
    function ysp_enhance_jquery_migrate( $scripts ) {
        if (!is_admin() && isset($scripts->registered['jquery'])) {
            $script = $scripts->registered['jquery'];
            
            if ($script->deps) { // Check whether the script has any dependencies
                $script->deps = array_diff($script->deps, array(
                    'jquery-migrate'
                ));
            }
        }
    }
}

/**
 * 05
 * 
 * Enhance Block Editor Assets
 */
if ( '1' != ysp_get_option('ysp-enhance-block-editor-assets') ) {
    add_action( 'wp_enqueue_scripts', 'ysp_enhance_block_editor_assets' );
}

if (!function_exists('ysp_enhance_block_editor_assets')) {
    function ysp_enhance_block_editor_assets(){
        wp_dequeue_style( 'wp-block-library' ); // WordPress core
        wp_dequeue_style( 'wp-block-library-theme' ); // WordPress core
        wp_dequeue_style( 'wc-blocks-style' ); // WooCommerce core
    }
}

/**
 * 06
 * 
 * Enhance ScrollMagic
 */
if ( '1' == ysp_get_option('ysp-enhance-scrollmagic') ) {
    add_action( 'wp_enqueue_scripts', 'ysp_enhance_scrollmagic' );
}

if (!function_exists('ysp_enhance_scrollmagic')) {
    function ysp_enhance_scrollmagic() {
        if ( wp_script_is( 'scroll_magic', 'registered' ) ) {
            wp_enqueue_script('scroll_magic');
        }
    }
}

/**
 * 07
 * 
 * Enhance Animations
 */
if ( '1' == ysp_get_option('ysp-enhance-animations') ) {
    add_action( 'wp_enqueue_scripts', 'ysp_enhance_animations' );
}

if (!function_exists('ysp_enhance_animations')) {
    function ysp_enhance_animations() {
        if ( wp_style_is( 'ysp_animations_style', 'registered' ) ) {
            wp_enqueue_style('ysp_animations_style');
        }
        if ( wp_script_is( 'ysp_animations_script', 'registered' ) ) {
            wp_enqueue_script('ysp_animations_script');
        }
    }
}

/**
 * 08
 * 
 * Admin stylesheet
 */
function ysp_admin_styles() {
	wp_enqueue_style( 'ysp-admin-styles', YSP_THEME_URI. '/inc/admin/css/style.css' );
}
add_action( 'admin_enqueue_scripts', 'ysp_admin_styles' );


/********************
    Extra
********************/

/**
 * 01
 *
 * Remove Comment Form Allowed Tags
 * @param array $defaults All the parameters of allowed form tags.
 * @return array
 *
 */
add_filter( 'comment_form_defaults', 'ysp_remove_comment_form_allowed_tags' );
if (!function_exists('ysp_remove_comment_form_allowed_tags')) {
    function ysp_remove_comment_form_allowed_tags( $defaults ) {
        $defaults['comment_notes_after'] = '';
        return $defaults;
    }
}

/**
 * 02
 *
 * Customize Comment Form Place Holder Input Text Fields & Labels
 * @link http://wpsites.net/web-design/customize-comment-form-place-holder-input-text-fields-labels/
 * @param array $fields All the parameters of the comment form fields.
 * @return array
 */
add_filter( 'comment_form_default_fields', 'ysp_comment_form_default_fields' );
if ( !function_exists('ysp_comment_form_default_fields') ) {
	function ysp_comment_form_default_fields( $fields ) {

		// Setup Variables.
		$commenter = wp_get_current_commenter();
		$req = get_option( 'require_name_email' );
        $aria_req = ( $req ? " aria-required='true'" : '' );
        
        // Translations
        $name = _x( 'Name', 'comment form author name' , YSP_TEXT_DOMAIN );
        $your_name = __( 'Your name', YSP_TEXT_DOMAIN );
        $email = __( 'E-mail', YSP_TEXT_DOMAIN );
        $your_email = __( 'Add e-mail address',  YSP_TEXT_DOMAIN );
        $domain = __( 'Domain',  YSP_TEXT_DOMAIN );
        $your_domain = __('Link To Your Own Domain', YSP_TEXT_DOMAIN);

        // Name
        $fields['author'] = '<p class="comment-form-author"><label for="author" class="comment-form__label">'. $name .'</label>'. ( $req ? '<span class="required"> *</span>' : '' ) .'<input id="author" class="comment-form__field" name="author" type="text" placeholder="'. $your_name .'" value="'. esc_attr( $commenter['comment_author'] ) .'" size="30"'. $aria_req .'/></p>';
        // Email
        $fields['email'] = '<p class="comment-form-email"><label for="email" class="comment-form__label">'. $email .'</label> ' . ( $req ? '<span class="required">*</span>' : '' ) .'<input id="email" class="comment-form__field" name="email" type="text" placeholder="'. $your_email .'" value="'. esc_attr( $commenter['comment_author_email'] ) .'" size="30"'. $aria_req .'/></p>';
        // URL
        $fields['url'] = '<p class="comment-form-url"><label for="url" class="comment-form__label">'. $domain .'</label><input id="url" class="comment-form__field" name="url" type="text" placeholder="'. $your_domain .'" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';
        
		return $fields;
	}
}

/**
 * 03
 *
 * Customize Comment Form Text Area & Label
 * @link http://wpsites.net/web-design/customize-comment-field-text-area-label/
 * @param array $args All the comment form html elements.
 * @return array
 */
add_filter( 'comment_form_defaults', 'ysp_comment_form_defaults' );
if ( !function_exists('ysp_comment_form_defaults') ) {
	function ysp_comment_form_defaults( $args ) {
        $comment = __( 'Comment', YSP_TEXT_DOMAIN );
        $your_feedback = __( 'Your Feedback Is Appreciated', YSP_TEXT_DOMAIN );
        
        // Comment Field
        $args['comment_field'] = '<p class="comment-form-comment"><label for="comment" class="comment-form__label">'. $comment .'</label><textarea id="comment" class="comment-form__field" name="comment" placeholder="'. $your_feedback .'"cols="45" rows="5" aria-required="true"></textarea></p>';
        
        // Submit
        $args['submit_button'] = '<input name="%1$s" type="submit" id="%2$s" class="submit c-button c-button--color-1" value="%4$s" />';

		return $args;
	}
}

/**
 * 04
 *
 * Customize Search Form Layout
 * @param array $form The search form html elements.
 * @return array
 */
add_filter('get_search_form', 'ysp_customize_search_form');
if ( !function_exists('ysp_customize_search_form') ) {
    function ysp_customize_search_form( $form ) {
        $form = '<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' ) ) . '">
				<label>
					<span class="screen-reader-text">' . _x( 'Search for:', 'label' ) . '</span>
					<input type="search" class="search-field" placeholder="' . esc_attr_x( 'Search &hellip;', 'placeholder' ) . '" value="' . get_search_query() . '" name="s" />
				</label>
				<input type="submit" class="search-submit c-button c-button--color-1" value="' . esc_attr_x( 'Search', 'submit button' ) . '" />
            </form>';
        return $form;
    }
}

/**
 * 05
 * 
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
add_filter( 'the_content', 'ysp_remove_empty_tags_around_shortcodes' );
if (!function_exists('ysp_remove_empty_tags_around_shortcodes')) {
    function ysp_remove_empty_tags_around_shortcodes( $content ) {
        $tags = array(
            '<p>[' => '[',
            ']</p>' => ']',
            ']<br>' => ']',
            ']<br />' => ']',
        );

        $content = strtr( $content, $tags );
        return $content;
    }
}

/**
 * 06
 * 
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 * @param array $args Configuration arguments.
 * @return array
 *
 */
if (!function_exists('ysp_page_menu_args')) {
    function ysp_page_menu_args( $args ) {
        $args['show_home'] = true;
        return $args;
    }
}

/**
 * 07
 * 
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
if (!function_exists('ysp_setup_author')) {
    function ysp_setup_author() {
        global $wp_query;

        if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
            $GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
        }
    }
}
add_action( 'wp', 'ysp_setup_author' );

/**
 * 08
 * 
 * We will need the following filter function to disable TinyMCE emojicons
 * Setting controlled by option 01
 */
if (!function_exists('ysp_disable_emojicons_tinymce')) {
    function ysp_disable_emojicons_tinymce($plugins) {
        if (is_array($plugins)) {
            return array_diff($plugins, array('wpemoji'));
        } else {
            return array();
        }
    }
}

/**
 * 09
 * 
 * Remove emoji CDN hostname from DNS prefetching hints.
 * Setting controlled by option 01
 */
if (!function_exists('ysp_disable_emojis_remove_dns_prefetch')) {
    function ysp_disable_emojis_remove_dns_prefetch( $urls, $relation_type ) {
        if ( 'dns-prefetch' == $relation_type ) {
            /** This filter is documented in wp-includes/formatting.php */
            $emoji_svg_url = apply_filters( 'emoji_svg_url', 'https://s.w.org/images/core/emoji/2.2.1/svg/' );

            $urls = array_diff( $urls, array( $emoji_svg_url ) );
        }

        return $urls;
    }
}

/**
 * 10
 * 
 * Allow shortcodes in text widget, widget title, menu titles.
 */
add_filter('widget_text', 'do_shortcode'); // Allow shortcode in text widget
add_filter('widget_title', 'ysp_shortcode_in_widget_title'); // Allow shortcode in widget title
if (!function_exists('ysp_shortcode_in_widget_title')) {
    function ysp_shortcode_in_widget_title($title){
        return do_shortcode(htmlspecialchars_decode($title));
    }
}
add_filter('wp_nav_menu', 'do_shortcode'); // Allow shortcode in menu titles

/**
 * 11
 * 
 * Custom WP-Gallery CSS
 * Custom WP gallery style and use our own style.
 */
add_filter( 'use_default_gallery_style', '__return_false' );

/**
 * 12
 * 
 * WordPress has trouble with the width and height attributes for SVGs. 
 * The width and height attributes can be removed for SVGs using this code adapted from trac ticket #26256
 *
 * Removes the width and height attributes of <img> tags for SVG
 * 
 * Without this filter, the width and height are set to "1" since
 * WordPress core can't seem to figure out an SVG file's dimensions.
 * 
 * For SVG's, returns an array with file url, width and height set 
 * to null, and false for 'is_intermediate'.
 * 
 * @wp-hook image_downsize
 * @param mixed $out Value to be filtered
 * @param int $id Attachment ID for image.
 * @return bool|array False if not in admin or not SVG. Array otherwise.
 */
if (!function_exists('ysp_fix_svg_size_attributes')) {
    function ysp_fix_svg_size_attributes( $out, $id ) {
        $image_url  = wp_get_attachment_url( $id );
        $file_ext   = pathinfo( $image_url, PATHINFO_EXTENSION );

        if ( is_admin() || 'svg' !== $file_ext ) {
            return false;
        }

        return array( $image_url, null, null, false );
    }
}
add_filter( 'image_downsize', 'ysp_fix_svg_size_attributes', 10, 2 ); 

/**
 * 13
 * 
 * Apparently custom nav menu walkers are not supported though they were supposed to be.
 */
add_filter( 'wp_nav_menu_args', function( $args ) {
    if ( isset( $args['walker'] ) && is_string( $args['walker'] ) && class_exists( $args['walker'] ) ) {
        $args['walker'] = new $args['walker'];
    }
    return $args;
}, 1001 ); // 1001 because \WP_Customize_Nav_Menus::filter_wp_nav_menu_args() runs at 1000.
