<?php
/**
 * Theme Shortcodes.
 */

/**
 *  YSP SHORTCODES
 * 14 Accordion [accordion][/accordion]
 * 15 Accordion Item [accordion_item][accordion_item].
 */

// Make sure to not redeclare the class
if ( !class_exists( 'YSP_Accordion_Shortcodes' ) ) :

class YSP_Accordion_Shortcodes {
    /**
     * Should the accordion JavaScript file be loaded the on the current page
     * False by default.
     */
    private $load_script = false;

    /**
     * Holds all the accordion shortcodes group settings.
     */
    private $script_data = array();

    /**
     * Count of each accordion group on a page.
     */
    private $group_count = 0;

    /**
     * Count for each accordion item within an accordion group.
     */
    private $item_count = 0;

    /**
     * Holds the accordion group container HTML tag.
     */
    private $wrapper_tag = 'div';

    /**
     * Holds the accordion item title HTML tag.
     */
    private $title_tag = 'h3';

    /**
     * Animation data attr.
     */
    private $anim = '';

    /**
     * Holds the accordion item content container HTML tag.
     */
    private $content_tag = 'div';

    /**
     * Class constructor
     * Sets up the plugin, including: textdomain, adding shortcodes, registering
     * scripts and adding buttons.
     */
    public function __construct() {
        // Load text domain
        load_plugin_textdomain(YSP_TEXT_DOMAIN, false, YSP_THEME_DIR.'/languages/');

        // Register JavaScript
        add_action('wp_enqueue_scripts', array($this, 'register_script'));

        add_shortcode('ysp_accordion', array($this, 'accordion_shortcode'));
        add_shortcode('ysp_accordion_item', array($this, 'accordion_item_shortcode'));

        // Print script in wp_footer
        add_action('wp_footer', array($this, 'print_script'));
    }

    /**
     * Registers the JavaScript file
     * If SCRIPT_DEBUG is set to true in the config file, the un-minified
     * version of the JavaScript file will be used.
     */
    public function register_script() {
        wp_register_script('accordion_script', get_template_directory_uri() . '/assets/libs/accordion.min.js', array('jquery', 'jquery-migrate'), '2.2.6', true);
    }

    /**
     * Prints the accordion JavaScript in the footer
     * This inlcludes both the accordion jQuery plugin file registered by
     * 'register_script()' and the accordion settings JavaScript variable.
     */
    public function print_script() {
        // Check to see if shortcodes are used on page
        if (!$this->load_script) {
            return;
        }

        wp_enqueue_script('accordion_script');

        // Output accordions settings JavaScript variable
        wp_localize_script('accordion_script', 'accordionShortcodesSettings', $this->script_data);
    }

    /**
     * Checks if a value is boolean.
     *
     * @param string $value The value to test
     *                      return bool
     */
    private function is_boolean( $value ) {
        return filter_var($value, FILTER_VALIDATE_BOOLEAN);
    }

    /**
     * Check for valid HTML tag
     * Checks the supplied HTML tag against a list of approved tags.
     *
     * @param string $tag The HTML tag to test
     *                    return string A valid HTML tag
     */
    private function check_html_tag( $tag ) {
        $tag = preg_replace('/\s/', '', $tag);
        $tags = array('h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'div');

        if (in_array($tag, $tags)) {
            return $tag;
        } else {
            return $this->title_tag;
        }
    }

    /**
     * Check for valid scroll value
     * Scroll value must be either an int or bool.
     *
     * @param int/bool $scroll The scroll offset integer or true/false
     *                         return int/bool The scroll offset integer else true/false
     */
    private function check_scroll_value( $scroll ) {
        $int = intval($scroll);

        if (is_int($int) && $int != 0) {
            return $int;
        } else {
            return $this->is_boolean($scroll);
        }
    }

    /**
     * Get's the ID for an accordion item.
     *
     * @param string $id If the user set an ID
     *                   return array The IDs for the accordion title and item
     */
    private function get_accordion_id( $id ) {
        $title_id = $id ? $id : "accordion-$this->group_count-t$this->item_count";
        $content_id = $id ? "content-$id" : "accordion-$this->group_count-c$this->item_count";

        return array(
            'title' => $title_id,
            'content' => $content_id,
        );
    }

    /**
     * Accordion group shortcode.
     */
    public function accordion_shortcode( $atts, $content = null ) {
        // The shortcode is used on the page, so load the JavaScript
        $this->load_script = true;

        // Set accordion counters
        ++$this->group_count;
        $this->item_count = 0;

        extract(
            shortcode_atts(
                array(
                    'tag' => '',
                    'autoclose' => true,
                    'openfirst' => false,
                    'openall' => false,
                    'clicktoclose' => false,
                    'scroll' => false,
                    'semantics' => '',
                    'class' => '',
                    'anim_data' => false,
                ),
                $atts,
                'accordion'
            )
        );

        // Set global HTML tag names
        // Set title HTML tag
        if ( $tag ) {
            $this->title_tag = $this->check_html_tag($tag);
        } else {
            $this->title_tag = 'h3';
        }

        if ( $anim_data ) {
            $this->anim = ' data-animate="'.$anim_data.'"';
        } else {
            $this->anim = '';
        }

        // Set wrapper HTML tags
        if ( $semantics == 'dl' ) {
            $this->wrapper_tag = 'dl';
            $this->title_tag = 'dt';
            $this->content_tag = 'dd';
        } else {
            $this->wrapper_tag = 'div';
            $this->content_tag = 'div';
        }

        // Set settings object (for use in JavaScript)
        $script_data = array(
            'id' => "accordion-$this->group_count",
            'autoClose' => $this->is_boolean($autoclose),
            'openFirst' => $this->is_boolean($openfirst),
            'openAll' => $this->is_boolean($openall),
            'clickToClose' => $this->is_boolean($clicktoclose),
            'scroll' => $this->check_scroll_value($scroll),
        );

        // Add this shortcodes settings instance to the global script data array
        $this->script_data[] = $script_data;

        return sprintf('<%2$s id="%3$s" class="accordion no-js%4$s" role="tablist"%5$s>%1$s</%2$s>',
            do_shortcode($content),
            $this->wrapper_tag,
            "accordion-$this->group_count",
            $class ? " $class" : '',
            $this->anim
        );
    }

    /**
     * Accordion item shortcode.
     */
    public function accordion_item_shortcode($atts, $content = null) {
        $options = shortcode_atts(
            array(
                'title' => '',
                'title_url' =>  '',
                'id' => '',
                'tag' => '',
                'class' => '',
                'icon_name_start' => '',
                'icon_prefix_start' => '',
                'icon_size_start' => '',
                'icon_color_start' => '',
                'icon_class_start' => '',
                'icon_rotate_start' => 'yes',
                'icon_name_end' => '',
                'icon_prefix_end' => '',
                'icon_size_end' => '',
                'icon_color_end' => '',
                'icon_class_end' => '',
                'icon_rotate_end' => 'yes',
            ),
            $atts
        );

        // Increment accordion item count
        ++$this->item_count;

        $ids = $this->get_accordion_id($options['id']);

        // Accordion URL
        $link_list = '';
        if ( $options['title_url'] ) {
            $link_list = ysp_generate_url_param_list($options['title_url']);
        }

        $icon_start_args = array(
            'icon_name' => $options['icon_name_start'],
            'icon_prefix' => $options['icon_prefix_start'],
            'icon_size' => $options['icon_size_start'],
            'icon_color' => $options['icon_color_start'],
            'icon_class' => $options['icon_class_start'],
        );

        $icon_end_args = array(
            'icon_name' => $options['icon_name_end'],
            'icon_prefix' => $options['icon_prefix_end'],
            'icon_size' => $options['icon_size_end'],
            'icon_color' => $options['icon_color_end'],
            'icon_class' => $options['icon_class_end'],
        );

        $icon_start = ysp_run_icon($icon_start_args);
        $icon_rotate_start = ($options['icon_rotate_start'] == 'yes') ? ' accordion-icon-rotate' : '';
        $icon_end = ysp_run_icon($icon_end_args);
        $icon_rotate_end = ($options['icon_rotate_end'] == 'yes') ? ' accordion-icon-rotate' : '';

        $accordion_title = sprintf('%8$s<%1$s id="%3$s" class="accordion-title%5$s" role="tab" aria-controls="%4$s" aria-selected="false" aria-expanded="false">%6$s%2$s%7$s</%1$s>%9$s',
            $options['tag'] ? $this->check_html_tag($options['tag']) : $this->title_tag,
            $options['title'] ? $options['title'] : '<span style="color:red;">'. __('Please enter a title attribute', YSP_TEXT_DOMAIN) .'</span>',
            $ids['title'],
            $ids['content'],
            $options['class'] ? ' '. $options['class'] : '',
            !empty($icon_start) ? "<span class=\"accordion-icon-start{$icon_rotate_start}\">{$icon_start}</span> " : '',
            !empty($icon_end) ? "<span class=\"accordion-icon-end{$icon_rotate_end}\">{$icon_end}</span>" : '',
            !empty($link_list) ? '<a '.$link_list.'>' : '',
            !empty($link_list) ? '</a>' : '',
        );

        $accordion_content = sprintf('<%1$s id="%3$s" class="accordion-content" role="tabpanel" aria-labelledby="%4$s" aria-hidden="true">%2$s</%1$s>',
            $this->content_tag,
            do_shortcode($content),
            $ids['content'],
            $ids['title']
        );

        return $accordion_title.$accordion_content;
    }
}

$YSP_Accordion_Shortcodes = new YSP_Accordion_Shortcodes();

endif;
