<?php
/**
 * Theme Site Filters.
 *
 * Contains the main site filter functions
 * Add dynamic classes via filter functions
 *
 * @package yourstyle_plus
 */

/**
 * Create class array to be used as css classes for frontend components
 *
 * @param array  $class CSS Classes for element.
 * @param string $filter_name Filter function name.
 * @return array
 */
if (!function_exists('ysp_get_css_class')) {
    function ysp_get_css_class( $class = '', $filter_name = '' ) {
        
        $classes = array();
        
        if ( ! empty( $class ) && ! empty( $filter_name ) ) {
            if ( ! is_array( $class ) ) {
                $class = preg_split( '#\s+#', $class );
            }
            $classes = array_merge( $classes, $class );
        } else {
            // Ensure that we always coerce class to being an array!
            $class = array();
        }

        $classes = array_map( 'esc_attr', $classes );

        /**
         * Filter the list of CSS body classes for the current post or page.
        *
        * @since 2.8.0
        *
        * @param array  $classes An array of body classes.
        * @param string $class   A comma-separated list of additional classes added to the body.
        */
        $classes = apply_filters( $filter_name , $classes, $class );

        return array_unique( $classes );
    }
}

/**
 * Theme Header css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array $class CSS Classes for element.
 */
if (!function_exists('ysp_site_header_class')) {
    function ysp_site_header_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_header_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Header Navigation css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array $class CSS Classes for element.
 */
if (!function_exists('ysp_site_header_navigation_class')) {
    function ysp_site_header_navigation_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_header_navigation_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Header Container css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array $class CSS Classes for element.
 */
if (!function_exists('ysp_site_header_container_class')) {
    function ysp_site_header_container_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_header_container_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Header layout left side classes
 * Separates classes with a single space, collates classes for element
 * uses return and not echo because it is being called in an echo statement
 * and would result in double echo
 *
 * @param array $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_header_layout_left_class')) {
    function ysp_header_layout_left_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_header_layout_left_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Header layout right side classes
 * Separates classes with a single space, collates classes for element
 * uses return and not echo because it is being called in an echo statement
 * and would result in double echo
 *
 * @param array $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_header_layout_right_class')) {
    function ysp_header_layout_right_class( $class = '', $clean_class = false ) {
        
        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_header_layout_right_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme main navigation css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array|string $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_site_nav_class')) {
    function ysp_site_nav_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class , 'ysp_site_nav_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme main mobile navigation css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array|string $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_site_mobile_nav_class')) {
    function ysp_site_mobile_nav_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class , 'ysp_site_mobile_nav_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Site content class
 * Separates classes with a single space, collates classes for element
 * uses return and not echo because it is being called in an echo statement
 * and would result in double echo
 *
 * @param array $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_site_content_class')) {
    function ysp_site_content_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_content_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Content layout css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array|string $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_content_area_class')) {
    function ysp_content_area_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_content_area_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Sidebar layout css class function
 * Separates classes with a single space, collates classes for element
 *
 * @param array $class CSS Classes for element.
 */
if (!function_exists('ysp_sidebar_area_class')) {
    function ysp_sidebar_area_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_sidebar_area_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Site footer class
 * Separates classes with a single space, collates classes for element
 * uses return and not echo because it is being called in an echo statement
 * and would result in double echo
 *
 * @param array $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_site_footer_class')) {
    function ysp_site_footer_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_footer_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}

/**
 * Theme Main Site footer widget class
 * Separates classes with a single space, collates classes for element
 * uses return and not echo because it is being called in an echo statement
 * and would result in double echo
 *
 * @param array $class CSS Classes for element.
 * @return string
 */
if (!function_exists('ysp_site_footer_widget_class')) {
    function ysp_site_footer_widget_class( $class = '', $clean_class = false ) {

        $classes = join( ' ', ysp_get_css_class( $class, 'ysp_site_footer_widget_class' ) );

        if ( ! empty( $classes ) ) :
            if ( $clean_class !== true ) {
                return ' class="' . esc_attr( $classes ) . '"';
            } else {
                return esc_attr( $classes );
            }
        endif;
    }
}