<?php
/**
 *	Class to Generate Typography Options
 *
 * @package yourstyle_plus
 */

/**
 *  Class to generate a list of fonts (add/remove)
 *  We need the list to be accessible globally (Singleton approach)
 *
 * @example $myfont = YspGenerateThemeFonts::get_instance();
 * @example $myfont->add_font('Open Sans', 'sans-serif', 'http://fonts.googleapis.com/css?family=Open+Sans:300,400,600,800','font-weight: 300','font-weight: 600');
 * @example $myfontChild = YspGenerateThemeFonts::get_instance();
 * @example $myfontChild ->remove_font('Open Sans');
 */
if (!class_exists('YspGenerateThemeFonts')) {
    class YspGenerateThemeFonts{

        private $fontList = array();

        private static $instance;

        private function __construct(){	}

        /**
         * Use a static method and a static property to mediate object instantiation
         * The $instance property is private and static, so it cannot be accessed from outside the class. The
         * get_instance() method has access though. Because get_instance() is public and static, it can be called via
         * the class from anywhere in a script.
         */
        public static function get_instance() {
            if ( empty( self::$instance ) ) {
                self::$instance = new YspGenerateThemeFonts();
            }
            return self::$instance;
        }

        /**
         * Create font definition array
         *
         * @param string $fontName Then name of the font-family ex.'Raleway';
         * @param string $fontStyle CSS default definition for selected font ex. 'sans-serif';
         * @param string $fontLink Link to font ex. 'http://fonts.googleapis.com/css?family=Raleway:200,300,400,600,900&subset=latin,latin-ext';
         * @param string $fontWeightBody body-font-weight';
         * @param string $fontWeightHeading heading-font-weight';
         */
        public function add_font( $fontName, $fontStyle, $fontLink, $fontWeightBody = 'font-weight:400', $fontWeightHeading = 'font-weight:700' ) {

            $font = array( $fontName, $fontStyle, $fontLink, $fontWeightBody, $fontWeightHeading );

            $font_id = strtolower( preg_replace('/\s*/', '',$fontName) ); 

            $this->fontList[$font_id] = $font;

            return $this->fontList;
        }

        /**
         * Funtion to remove a font from font definition array using font name
         * Run a foreach to search for font familiy name in a multi-array
         * If found unset the single font definition array from the multi-array
         *
         * @param string $fontName Font family name ex. 'Raleway'
         * @example $myfont = YspGenerateThemeFonts::get_instance(); $myfont->remove_font('Raleway');
         */
        public function remove_font( $fontName ) {

            $fonts = $this->fontList;

            foreach ( $fonts as $key => $singlefont ) {
                if ( in_array( $fontName, $singlefont ) ) {						
                    unset( $fonts[ $key ] );
                }
            }
            
            $this->fontList = $fonts;
        }

        public function return_font_list() {		
            return $this->fontList;
        }
    }
}
/**
 * Call theme font list
 *
 * @example $theme_fonts = new YspGetThemeFonts;
 * @example $list_fonts = $theme_fonts->get_fonts();
 * @example $list_fonts = $theme_fonts->get_fonts_name();
 */
if (!class_exists('YspGetThemeFonts')) {
    class YspGetThemeFonts{
        /**
         * Need to implement the following check before this class executes
         *
         * @todo 'return !empty($this->fontList) ? $this->fontList : array('no fonts defined');'
         */

        private $fontList;
        private $fontNameList;
        private $font_link;

        public function __construct() {
            $this->fontList = YspGenerateThemeFonts::get_instance()->return_font_list();
        }

        /**
         * Return a multidimensional array of fonts avaliable
         */
        public function get_fonts() {		
            // Add empty element
            return $this->fontList;		
        }

        /**
         * Return a simple array of fonts names avaliable
         */
        public function get_fonts_name() {

            foreach ( $this->fontList as $key => $font ) {
                /*
                * $font[0] = Font Name / font family
                * $font[1] = generic family ex. "serif", "sans-serif", "cursive" ...
                * $font[2] = font http:// link
                * $font[3] = default weight normal
                * $font[4] = default weight bold
                */
                $this->fontNameList[ $key ] = $font[0];
            }
            return $this->fontNameList;
        }


        public function get_theme_fonts_link() {

            $theme_fonts = $this->get_fonts(); // Get registered fonts.

            $font_body_option = ysp_get_option('ysp-typography-body-font');
            $font_body = $font_body_option !== 'default' ? $font_body_option : '';
            // $subset = ysp_get_option('ysp_font_family_subset') ? '&subset=latin,latin-ext' : '';

            $font_heading = '';
            $font_heading_prep = '';
            $font_heading_option = ysp_get_option('ysp-typography-heading-font');

            $this->font_link = ($font_body) ? $theme_fonts[ $font_body ][2] : '';

            if ( $font_heading_option !== 'default' ) {
                $font_heading = $font_heading_option; // Get selected font family option.
                $font_heading_prep = str_replace( 'https://fonts.googleapis.com/css?family=','|', $theme_fonts[ $font_heading ][2] );
            }

            if ( $font_body !== $font_heading ) {

                $this->font_link = ($font_body) ? $theme_fonts[ $font_body ][2].$font_heading_prep : '';
            }

            return $this->font_link;
            // return $this->font_link.$subset;
        }

        public function get_theme_font_style() {

            $theme_fonts = $this->get_fonts(); // Get registered fonts.		

            $font_body_option = ysp_get_option('ysp-typography-body-font');
            $font_body = $font_body_option !== 'default' ? $font_body_option : '';
            $font_heading_option = ysp_get_option('ysp-typography-heading-font');
            $font_heading = $font_heading_option !== 'default' ? $font_heading_option : '';

            $font_heading_status = $font_heading_option !== 'default' ? true : false;

            $select_b = 'html, body, button, input, optgroup, select, textarea, .u-font-family-one';
            $select_h = 'h1, h2, h3, h4, h5, h6, .u-font-family-two';
            $font_one =	'.u-font-family-one';
            $font_two = '.u-font-family-two';

            $style = '';
            $render_heading_font = '';
            
            // If no secondary font.
            if ( !$font_heading_status ) {

                $style = ($font_body) ? $select_b.','.$select_h.'{font-family:\''. esc_attr( $theme_fonts[ $font_body ][0] ) . '\','.esc_attr( $theme_fonts[ $font_body ][1]).';'. $theme_fonts[ $font_body ][3] .';}' : '';

                // If font weight is not the same add heading font weight.
                $style .= ($font_body) ? $theme_fonts[ $font_body ][3] !== $theme_fonts[ $font_body ][4] ? $select_h.'{'.$theme_fonts[ $font_body ][4].';}' : '' : '';
                
                // Load the body font only
                $style .= ':root{--font-family-one:'.esc_attr( $theme_fonts[ $font_body ][0] ).';}';
            }

            // If there is secondary font and it is the same as the body font, concatenate the body and heading selectors.
            if ( $font_heading_status && $font_heading === $font_body ) {

                $style = ($font_body) ? $select_b.','.$select_h.'{font-family:\''. esc_attr( $theme_fonts[ $font_body ][0] ) . '\','.esc_attr( $theme_fonts[ $font_body ][1]).';'. $theme_fonts[ $font_body ][3] .';}' : '';

                // If font weight is not the same add heading font weight.
                $style .= ($font_body) ? $theme_fonts[ $font_body ][3] !== $theme_fonts[ $font_body ][4] ? $select_h.'{'.$theme_fonts[ $font_body ][4].';}' : '' : '';

                // Add the heading font
                $render_body_font = ($font_body) ? '--font-family-one:'.esc_attr( $theme_fonts[ $font_body ][0] ).';' : '';
                $render_heading_font = ($font_heading) ? '--font-family-two:'.esc_attr( $theme_fonts[ $font_heading ][0] ).';' : '';

                // Load the body font and heading font
                $style .= ':root{'. $render_body_font . $render_heading_font .'}';
            }

            // If there is secondary font and it is NOT the same as the body font.
            if ( $font_heading_status && $font_heading !== $font_body ) {

                $style = ($font_body) ? $select_b.'{font-family:\''. esc_attr( $theme_fonts[ $font_body ][0] ) . '\','.esc_attr( $theme_fonts[ $font_body ][1]).';'. $theme_fonts[ $font_body ][3] .';}' : '';

                $style .= ($font_heading) ? $select_h.'{font-family:\''. esc_attr( $theme_fonts[ $font_heading ][0] ) . '\','.esc_attr( $theme_fonts[ $font_heading ][1]).';'. $theme_fonts[ $font_heading ][4] .';}' : '';

                // Font Family selectors without font weight
                $style .= ($font_body) ? $font_one.'{font-family:\''. esc_attr( $theme_fonts[ $font_body ][0] ) . '\','.esc_attr( $theme_fonts[ $font_body ][1]).';}' : '';
                $style .= ($font_heading) ? $font_two.'{font-family:\''. esc_attr( $theme_fonts[ $font_heading ][0] ) . '\','.esc_attr( $theme_fonts[ $font_heading ][1]).';}' : '';
                
                // Add the heading font
                $render_body_font = ($font_body) ? '--font-family-one:'.esc_attr( $theme_fonts[ $font_body ][0] ).';' : '';
                $render_heading_font = ($font_heading) ? '--font-family-two:'.esc_attr( $theme_fonts[ $font_heading ][0] ).';' : '';
                
                // Load the body font and heading font
                $style .= ':root{'. $render_body_font . $render_heading_font .'}';
            }

            return $style;
        }
    }
}

// Wrapper function to init font administration
if (!function_exists('ysp_fonts_setup')) {
    function ysp_fonts_setup(){	
        return YspGenerateThemeFonts::get_instance();
    }
}