<?php
/**
 * Menu item custom fields example.
 *
 * @version 0.2.0
 *
 * @author Dzikri Aziz <kvcrvt@gmail.com>
 *
 *
 * Plugin name: Menu Item Custom Fields Example
 * Plugin URI: https://github.com/kucrut/wp-menu-item-custom-fields
 * Description: Example usage of Menu Item Custom Fields in plugins/themes
 * Version: 0.2.0
 * Author: Dzikri Aziz
 * Author URI: http://kucrut.org/
 * License: GPL v2
 * Text Domain: menu-item-custom-fields-example
 */

/**
 * Sample menu item metadata.
 *
 * This class demonstrate the usage of Menu Item Custom Fields in plugins/themes.
 *
 * @since 0.1.0
 */
if (!class_exists('Mega_Menu_Item_Settings')) {
    class Mega_Menu_Item_Settings {

        /**
         * Holds our custom fields.
         *
         * @var array
         *
         * @since  Mega_Menu_Item_Settings 0.2.0
         */
        protected static $fields = array();

        /**
         * Initialize plugin.
         */
        public static function init() {
            add_action( 'wp_nav_menu_item_custom_fields', array( __CLASS__, '_fields' ), 10, 4 );
            add_action( 'wp_update_nav_menu_item', array( __CLASS__, '_save' ), 10, 3 );
            add_filter( 'manage_nav-menus_columns', array( __CLASS__, '_columns' ), 99 );

            self::$fields = array(
                // Fields that contain depth should be arranged based on depth number
                'ysp-enable-mega-menu' => array(
                    'label' => __( 'Enable Mega Menu', 'yourstyle-plus' ),
                    'type'  => 'checkbox',
                    'depth' => 0,
                    'limit' => 0,
                ),
                'ysp-mega-menu-divider' => array(
                    'label' => __( 'End Column', 'yourstyle-plus' ),
                    'type'  => 'checkbox',
                    'depth' => 1,
                    'limit' => 1,
                ),
                'ysp-disable-menu-link' => array(
                    'label' => __( 'Disable Link', 'yourstyle-plus' ),
                    'type'  => 'checkbox',
                ),
                'ysp-menu-button-type' => array(
                    'label' => __( 'Button', 'yourstyle-plus' ),
                    'type'  => 'select-button-type',
                ),
            );
        }

        /**
         * Save custom field value.
         *
         * @wp_hook action wp_update_nav_menu_item
         *
         * @param int   $menu_id         Nav menu ID
         * @param int   $menu_item_db_id Menu item ID
         * @param array $menu_item_args  Menu item data
         */
        public static function _save( $menu_id, $menu_item_db_id, $menu_item_args ) {
            if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
                return;
            }

            check_admin_referer( 'update-nav_menu', 'update-nav-menu-nonce' );

            foreach ( self::$fields as $_key => $label ) {
                $key = sprintf( 'menu-item-%s', $_key );

                // Sanitize
                if ( ! empty( $_POST[ $key ][ $menu_item_db_id ] ) ) {
                    // Do some checks here...
                    $value = $_POST[ $key ][ $menu_item_db_id ];
                } else {
                    $value = null;
                }

                // Update
                if ( ! is_null( $value ) ) {
                    update_post_meta( $menu_item_db_id, $key, $value );
                } else {
                    delete_post_meta( $menu_item_db_id, $key );
                }
            }
        }

        /**
         * Print field.
         *
         * @param object $item  menu item data object
         * @param int    $depth Depth of menu item. Used for padding.
         * @param array  $args  menu item args
         * @param int    $id    nav menu ID
         *
         * @return string Form fields
         */
        public static function _fields( $id, $item, $depth, $args ) {

            foreach ( self::$fields as $_key => $data ) :
                
                $key   = sprintf( 'menu-item-%s', $_key );
                $id    = sprintf( 'edit-%s-%s', $key, $item->ID );
                $name  = sprintf( '%s[%s]', $key, $item->ID );
                $value = get_post_meta( $item->ID, $key, true );
                $class = sprintf( 'field-%s', $_key );

                /**
                 * Check if field is limited to a certain depth
                 * Check if we set a depth show it only starting from that depth
                */
                if ( isset( $data['limit'] ) ) {
                    if ( $data['limit'] === $depth ) {
                        self::_render_field( $id, $key, $name, $value, $class, $data );
                    }
                } elseif ( isset( $data['depth'] ) ) {
                    if ( $depth >= $data['depth'] ) {
                        self::_render_field( $id, $key, $name, $value, $class, $data );
                    }
                } else {
                    self::_render_field( $id, $key, $name, $value, $class, $data );
                }
                
            endforeach;
        }

        public static function _render_field( $id, $key, $name, $value, $class, $data ) {

            $data_type = isset( $data['type'] ) ? $data['type'] : 'text';

            ?>
            <p class="description description-wide <?php echo esc_attr( $class ); ?>">
            <?php
            if ( 'text' === $data_type ) {
                printf(
                    '<label for="%1$s">%2$s<br /><input type="text" id="%1$s" class="widefat %1$s" name="%3$s" value="%4$s" /></label>',
                    esc_attr( $id ),
                    esc_html( $data['label'] ),
                    esc_attr( $name ),
                    esc_attr( $value )
                );
            } elseif ( 'checkbox' === $data_type ) {
                printf(
                    '<label for="%1$s"><input type="checkbox" id="%1$s" class="widefat %1$s" name="%3$s" value="true" %4$s/> %2$s</label>',
                    esc_attr( $id ),
                    esc_html( $data['label'] ),
                    esc_attr( $name ),
                    ( isset( $value ) ? checked( $value, 'true', false ) : '' )
                );
            } elseif ( 'select-button-type' === $data_type ) {
                printf(
                    '<label for="%1$s">%2$s
                    <select id="%1$s" name="%3$s" class="widefat">
                        <option value="">'. __( 'None', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-1" ' . ( isset( $value ) ? selected( $value, 'c-button--color-1', false ) : '' ) . '>'. __( 'Color 1', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-2" ' . ( isset( $value ) ? selected( $value, 'c-button--color-2', false ) : '' ) . '>'. __( 'Color 2', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-3" ' . ( isset( $value ) ? selected( $value, 'c-button--color-3', false ) : '' ) . '>'. __( 'Color 3', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-4" ' . ( isset( $value ) ? selected( $value, 'c-button--color-4', false ) : '' ) . '>'. __( 'Color 4', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-5" ' . ( isset( $value ) ? selected( $value, 'c-button--color-5', false ) : '' ) . '>'. __( 'Color 5', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-6" ' . ( isset( $value ) ? selected( $value, 'c-button--color-6', false ) : '' ) . '>'. __( 'Color 6', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-7" ' . ( isset( $value ) ? selected( $value, 'c-button--color-7', false ) : '' ) . '>'. __( 'Color 7', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-8" ' . ( isset( $value ) ? selected( $value, 'c-button--color-8', false ) : '' ) . '>'. __( 'Color 8', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-9" ' . ( isset( $value ) ? selected( $value, 'c-button--color-9', false ) : '' ) . '>'. __( 'Color 9', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--color-0" ' . ( isset( $value ) ? selected( $value, 'c-button--color-0', false ) : '' ) . '>'. __( 'Color 10', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-1" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-1', false ) : '' ) . '>'. __( 'Color Outline 1', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-2" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-2', false ) : '' ) . '>'. __( 'Color Outline 2', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-3" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-3', false ) : '' ) . '>'. __( 'Color Outline 3', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-4" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-4', false ) : '' ) . '>'. __( 'Color Outline 4', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-5" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-5', false ) : '' ) . '>'. __( 'Color Outline 5', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-6" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-6', false ) : '' ) . '>'. __( 'Color Outline 6', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-7" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-7', false ) : '' ) . '>'. __( 'Color Outline 7', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-8" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-8', false ) : '' ) . '>'. __( 'Color Outline 8', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-9" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-9', false ) : '' ) . '>'. __( 'Color Outline 9', YSP_TEXT_DOMAIN ) .'</option>
                        <option value="c-button--outline-color-0" ' . ( isset( $value ) ? selected( $value, 'c-button--outline-color-0', false ) : '' ) . '>'. __( 'Color Outline 10', YSP_TEXT_DOMAIN ) .'</option>
                    </select></label>',
                    esc_attr( $id ),
                    esc_html( $data['label'] ),
                    esc_attr( $name )
                );
            }
            ?>
            </p>
            <?php
        }

        /**
         * Add our fields to the screen options toggle.
         *
         * @param array $columns Menu item columns
         *
         * @return array
         */
        public static function _columns( $columns ) {
            $custom_columns = array(
                'ysp-enable-mega-menu' => __( 'Enable Mega Menu', 'yourstyle-plus' ),
                'ysp-mega-menu-divider' => __( 'End Column', 'yourstyle-plus' ),
                'ysp-disable-menu-link' => __( 'Disable Link', 'yourstyle-plus' ),
                'ysp-menu-button-type' => __( 'Button Type', 'yourstyle-plus' ),
            );
            
            $columns = array_merge( $columns, $custom_columns );

            return $columns;
        }
    }
}
Mega_Menu_Item_Settings::init();