<?php
/**
 * YSP_Walker_Nav_Menu class
 */

/**
 * Custom Class used to implement an HTML list of nav menu items.
 *
 * @see Walker_Nav_Menu
 */
if ( !class_exists('YSP_Walker_Nav_Menu') ) {
    class YSP_Walker_Nav_Menu extends Walker_Nav_Menu {
        private $currentItem;

        /**
         * Starts the list before the elements are added.
         *
         * @since 3.0.0
         *
         * @see Walker::start_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        public function start_lvl( &$output, $depth = 0, $args = null ) {
            $item = $this->currentItem;
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent = str_repeat( $t, $depth );

            // Default class.
            $classes = array( 'sub-menu' );

            /**
             * Filters the CSS class(es) applied to a menu list element.
             *
             * @since 4.8.0
             *
             * @param string[] $classes Array of the CSS classes that are applied to the menu `<ul>` element.
             * @param stdClass $args    An object of `wp_nav_menu()` arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $class_names = join( ' ', apply_filters( 'nav_menu_submenu_css_class', $classes, $args, $depth ) );
            $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';
            
            $column_start = '';
            $mega_menu = get_post_meta( $item->ID, 'menu-item-ysp-enable-mega-menu', true );
            if ($mega_menu) {
                $column_start .= '<div class="mega-menu-column">';
            }

            if ( $depth === 0 && $mega_menu ) {
                $output .= "{$n}{$indent}<div class=\"mega-menu-wrapper\"><ul class=\"mega-menu-inner\">{$column_start}{$n}";
            } else {
                $output .= "{$n}{$indent}<ul$class_names>{$n}";
            }
        }

        /**
         * Starts the element output.
         *
         * @since 3.0.0
         * @since 4.4.0 The {@see 'nav_menu_item_args'} filter was added.
         *
         * @see Walker::start_el()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param WP_Post  $item   Menu item data object.
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         * @param int      $id     Current item ID.
         */
        public function start_el( &$output, $item, $depth = 0, $args = null, $id = 0 ) {
            $this->currentItem = $item;
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            
            $indent = ( $depth ) ? str_repeat( $t, $depth ) : '';
            
            $item_tag = 'a';

            $classes   = empty( $item->classes ) ? array() : (array) $item->classes;
            $classes[] = 'menu-item-' . $item->ID;

            // Check if Mega Menu is enabled.
            $mega_menu = get_post_meta( $item->ID, 'menu-item-ysp-enable-mega-menu', true );
            if ( $depth === 0 && $mega_menu ) {
                if ( $mega_menu ) {
                    $classes[] = 'mega-menu-enabled';
                }
            }

            // Check if menu is set to behave like a submenu open trigger
            $disable_menu_link = get_post_meta( $item->ID, 'menu-item-ysp-disable-menu-link', true );
            if ( $disable_menu_link === 'true' ) {
                $classes[] = 'menu-item--show-submenu';
            }

            // Check if the button option is enabled and add classes
            $menu_button_type = get_post_meta( $item->ID, 'menu-item-ysp-menu-button-type', true );
            if ( $menu_button_type !== '' ) {
                $classes[] = 'menu-item--has-button';
            }

            /**
             * Filters the arguments for a single nav menu item.
             *
             * @since 4.4.0
             *
             * @param stdClass $args  An object of wp_nav_menu() arguments.
             * @param WP_Post  $item  Menu item data object.
             * @param int      $depth Depth of menu item. Used for padding.
             */
            $args = apply_filters( 'nav_menu_item_args', $args, $item, $depth );

            /**
             * Filters the CSS classes applied to a menu item's list item element.
             *
             * @since 3.0.0
             * @since 4.1.0 The `$depth` parameter was added.
             *
             * @param string[] $classes Array of the CSS classes that are applied to the menu item's `<li>` element.
             * @param WP_Post  $item    The current menu item.
             * @param stdClass $args    An object of wp_nav_menu() arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
            $class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

            /**
             * Filters the ID applied to a menu item's list item element.
             *
             * @since 3.0.1
             * @since 4.1.0 The `$depth` parameter was added.
             *
             * @param string   $menu_id The ID that is applied to the menu item's `<li>` element.
             * @param WP_Post  $item    The current menu item.
             * @param stdClass $args    An object of wp_nav_menu() arguments.
             * @param int      $depth   Depth of menu item. Used for padding.
             */
            $id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );
            $id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

            $output .= $indent . '<li' . $id . $class_names . '>';

            $atts           = array();
            $atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
            $atts['target'] = ! empty( $item->target ) ? $item->target : '';
            if ( '_blank' === $item->target && empty( $item->xfn ) ) {
                $atts['rel'] = 'noopener noreferrer';
            } else {
                $atts['rel'] = $item->xfn;
            }
            $atts['href']         = ! empty( $item->url ) ? $item->url : '';
            $atts['aria-current'] = $item->current ? 'page' : '';

            /** This filter is documented in wp-includes/post-template.php */
            $title = apply_filters( 'the_title', $item->title, $item->ID );

            /**
             * Filters a menu item's title.
             *
             * @since 4.4.0
             *
             * @param string   $title The menu item's title.
             * @param WP_Post  $item  The current menu item.
             * @param stdClass $args  An object of wp_nav_menu() arguments.
             * @param int      $depth Depth of menu item. Used for padding.
             */
            $title = apply_filters( 'nav_menu_item_title', $title, $item, $args, $depth );

		    $link_class = '';
		    $link_class .= 'site-navigation__link'; // Default Link Class
            if ( $depth === 0 || $depth === 1 ) {
                $link_class .= ($depth === 0) ? ' menu-item-first-link': '';
                $link_class .= ($depth === 1) ? ' menu-item-first-sub-link' : '';
            }

            // Check if menu is set to behave like a submenu open trigger
            $disable_menu_link = get_post_meta( $item->ID, 'menu-item-ysp-disable-menu-link', true );
            if ( $disable_menu_link === 'true' ) {
                $item_tag  = 'div';
            }
            
            // Check if the button option is enabled and add classes
            $menu_button_type = get_post_meta( $item->ID, 'menu-item-ysp-menu-button-type', true );
            if ( $menu_button_type !== '' ) {
		        $link_class = 'c-button '. $menu_button_type;
            }

		    $attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
            $attributes .= ! empty( $item->target ) && $item_tag !== 'div' ? ' target="' . esc_attr( $item->target ) . '"' : '';
            $attributes .= ! empty( $item->xfn ) && $item_tag !== 'div' ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
            $attributes .= ! empty( $item->url ) && $item_tag !== 'div' ? ' href="' . esc_attr( $item->url ) . '"' : '';

            $link_chevron = ( $depth === 0 && in_array('menu-item-has-children', $item->classes) ) ? '<span class="menu-item-symbol"></span>' : '';

            $item_output = $args->before;
                $item_output .= '<' . $item_tag . ' class="' . $link_class .'"'. $attributes . '>';
                    $item_output .= $args->link_before . $title . $args->link_after . $link_chevron;
                $item_output .= '</' . $item_tag . '>';
            $item_output .= $args->after;

            /**
             * Filters a menu item's starting output.
             *
             * The menu item's starting output only includes `$args->before`, the opening `<a>`,
             * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
             * no filter for modifying the opening and closing `<li>` for a menu item.
             *
             * @since 3.0.0
             *
             * @param string   $item_output The menu item's starting HTML output.
             * @param WP_Post  $item        Menu item data object.
             * @param int      $depth       Depth of menu item. Used for padding.
             * @param stdClass $args        An object of wp_nav_menu() arguments.
             */
            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
        }

        /**
         * Ends the element output, if needed.
         *
         * @since 3.0.0
         *
         * @see Walker::end_el()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param WP_Post  $item   Page data object. Not used.
         * @param int      $depth  Depth of page. Not Used.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        public function end_el( &$output, $item, $depth = 0, $args = null ) {
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }

		    $column_break = '';
            $mega_menu = get_post_meta( $item->ID, 'menu-item-ysp-mega-menu-divider', true );
            if ($mega_menu) {
                $column_break .= '</div><div class="mega-menu-column">';
            }

            if ( $depth === 1 ) {
                $output .= '</li>'. $column_break ."{$n}";
            } else {
                $output .= '</li>';
            }
        }

        /**
         * Ends the list of after the elements are added.
         *
         * @since 3.0.0
         *
         * @see Walker::end_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        public function end_lvl( &$output, $depth = 0, $args = null ) {
            $item = $this->currentItem;
            if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
                $t = '';
                $n = '';
            } else {
                $t = "\t";
                $n = "\n";
            }
            $indent  = str_repeat( $t, $depth );
            
            $column_end = '';
            $mega_menu = get_post_meta( $item->ID, 'menu-item-ysp-enable-mega-menu', true );
            if ($mega_menu) {
                $column_end = '</div>';
            }

            if ( $depth === 0 ) {
                $output .= "{$indent}{$column_end}</ul>{$n}";
            } else {
                $output .= "{$indent}</ul>{$n}";
            }
        }

    } // YSP_Walker_Nav_Menu
}
