<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package yourstyle+
 */

if (!function_exists('get_site_logo_url')) {
    /**
     * Get the custom header logo url
     * 
     * @return string
     */
    function get_site_logo_url() {
		$custom_logo_id = get_theme_mod('custom_logo');
		if (!empty($custom_logo_id)) {
			$site_logo = wp_get_attachment_image_src($custom_logo_id, 'medium');
			$site_logo = $site_logo[0];
		} else {
			// Return default logo placeholder when no logo is set in customizer
			$site_logo = get_template_directory_uri().'/assets/src/images/yourstyle-plus-logo.svg';
		}
		return $site_logo;
	}
}

if (!function_exists('ysp_posted_by')) {
	/**
	 * Prints HTML with meta information for the current author.
	 */
    function ysp_posted_by($author_only = FALSE) {
        if ($author_only) {
            $meta_author = '<span class="author vcard">' . esc_html(get_the_author()) . '</span>';
        } else {
            $meta_author = sprintf(
                /* translators: %s: post author. */
                esc_html_x('By %s', 'post author', YSP_TEXT_DOMAIN),
                '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>'
           );
        }

        $icon = shortcode_exists('icon') ? '<span class="meta-icon">'. do_shortcode('[icon name="user" prefix="fal"]') .'</span>': '';

		echo '<div class="meta-item meta-author">'. $icon .'<span class="meta-text">'. $meta_author .'</span></div>'; // WPCS: XSS OK.
	}
}

if (!function_exists('ysp_posted_on')) {
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
    function ysp_posted_on($date_only = TRUE) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf($time_string,
			esc_attr(get_the_date(DATE_W3C)),
			esc_html(get_the_date()),
			esc_attr(get_the_modified_date(DATE_W3C)),
			esc_html(get_the_modified_date())
		);

        if ($date_only) {
            $meta_date = $time_string;
        } else {
            $meta_date = sprintf(
                /* translators: %s: post date. */
                esc_html_x('Posted on %s', 'post date', YSP_TEXT_DOMAIN),
                $time_string
           );
        }

        $icon = shortcode_exists('icon') ? '<span class="meta-icon">'. do_shortcode('[icon name="calendar" prefix="fal"]') .'</span>': '';

		echo '<div class="meta-item meta-date">'. $icon .'<span class="meta-text">'. $meta_date .'</span></div>'; // WPCS: XSS OK.
	}
}

if (!function_exists('ysp_posted_comments')) {
	/**
	 * Prints HTML with meta information for the current comments.
	 */
    function ysp_posted_comments() {

		if (! post_password_required() && (comments_open() || get_comments_number())) {

            $icon = shortcode_exists('icon') ? '<span class="meta-icon">'. do_shortcode('[icon name="comment-alt" prefix="fal"]') .'</span>': '';

            echo '<div class="meta-item meta-comments">'. $icon .'<span class="meta-text">';
                comments_popup_link(
                    sprintf(
                        wp_kses(
                            /* translators: %s: post title */
                            __('Leave a Comment<span class="screen-reader-text"> on %s</span>', YSP_TEXT_DOMAIN),
                            array(
                                'span' => array(
                                    'class' => array(),
                                ),
                            )
                        ),
                        get_the_title()
                    )
                );
            echo '</span></div>'; // WPCS: XSS OK.

        }
	}
}

if (!function_exists('ysp_posted_in')) {
	/**
	 * Prints HTML with meta information for the current categories.
	 */
    function ysp_posted_in($categories_only = FALSE) {
		if ('post' === get_post_type()) {
            /* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list(esc_html__(', ', YSP_TEXT_DOMAIN));
			if ($categories_list) {
                if ($categories_only) {
                    printf('<span class="cat-links">%1$s</span>', $categories_list); // WPCS: XSS OK.
                } else {
                    /* translators: 1: list of categories. */
                    printf('<span class="cat-links">' . esc_html__('Posted in: %1$s', YSP_TEXT_DOMAIN) . '</span>', $categories_list); // WPCS: XSS OK.
                }
            }
        }
	}
}

if (!function_exists('ysp_excerpt_length')) {
    /**
     * Default Excerpt Length
     */
	function ysp_excerpt_length() {
        $length = ysp_get_option('ysp-blog-excerpt-length');
        return $length;
	}
}

if (!function_exists('ysp_excerpt_readmore')) {
    /**
     * Custom excerpt read more link
     */
	function ysp_excerpt_readmore() {
        $post = get_post();
        $more = '';
		if ($post->post_excerpt) {
            $more .= '&hellip; <br/><a class="view-article" href="'. get_permalink($post->ID) .'">'. __('Read more', YSP_TEXT_DOMAIN) .'</a>';
        }
        return $more;
	}
}

if (!function_exists('ysp_excerpt')) {
    /**
     * Custom excerpt callback
     */
	function ysp_excerpt($length_callback = '', $more_callback = '', $echo = TRUE) {
        $output = '';

        // Excerpt Length
        $length = !empty($length_callback) ? $length_callback : ysp_excerpt_length();
        
        // Excerpt More
        $more = !empty($more_callback) ? $more_callback : ysp_excerpt_readmore();
        
        // Excerpt Output
		$excerpt = get_the_excerpt();
		$excerpt = wptexturize($excerpt);
        $excerpt = convert_chars($excerpt);
        $output = wp_trim_words($excerpt, $length, $more);
        
        if ($echo == TRUE) {
            echo '<p class="post-excerpt">'. $output .'<p>';
        } else {
            return $output;
        }
	}
}

if (!function_exists( 'ysp_post_thumbnail')) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
    function ysp_post_thumbnail()
    {
		if (post_password_required() || is_attachment() || ! has_post_thumbnail()) {
			return;
		}

		if (is_singular()) {
        ?>

			<div class="post-thumbnail">
                <?php echo get_the_post_thumbnail( get_the_ID(), 'large', array( 'class' => 'entry-featured-image' ) ); ?>
			</div><!-- .post-thumbnail -->

        <?php } else { ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
                the_post_thumbnail( 'post-thumbnail', array(
                    'alt' => the_title_attribute( array(
                        'echo' => false,
                    ) ),
                ) );
			?>
		</a>

		<?php
		}
	}
}

if (!function_exists('ysp_entry_footer')) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
    function ysp_entry_footer()
    {
        $display_cats = ysp_get_option('ysp-blog-single-categories');
        $display_tags = ysp_get_option('ysp-blog-single-tags');

		// Hide category and tag text for pages.
		if ('post' === get_post_type()) {
            echo (is_singular() && ($display_cats || $display_tags)) ? '<hr>' : '';
			/* translators: used between list items, there is a space after the comma */
            $categories_list = get_the_category_list(esc_html__(', ', YSP_TEXT_DOMAIN));
			if ( $display_cats && $categories_list ) {
				/* translators: 1: list of categories. */
				printf('<span class="cat-links">' . esc_html__('Posted in: %1$s', YSP_TEXT_DOMAIN) . '</span>', $categories_list); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list('', esc_html_x(', ', 'list item separator', YSP_TEXT_DOMAIN));
			if ( $display_tags && $tags_list ) {
				/* translators: 1: list of tags. */
				printf('<span class="tags-links">' . esc_html__('Tagged: %1$s', YSP_TEXT_DOMAIN) . '</span>', $tags_list); // WPCS: XSS OK.
			}
		}
	}
}